| Title: | A Multi-Platform GUI for Drawing Customizable Graphs in R |
|---|---|
| Description: | A multi-platform user interface for drawing highly customizable graphs in R. It aims to be a valuable help to quickly draw publishable graphs without any knowledge of R commands. Six kinds of graph are available: histogram, box-and-whisker plot, bar plot, pie chart, curve and scatter plot. |
| Authors: | Maxime HERVE |
| Maintainer: | Maxime HERVE <[email protected]> |
| License: | GPL-2 |
| Version: | 1.9-86-5 |
| Built: | 2026-05-20 06:54:06 UTC |
| Source: | https://github.com/cran/GrapheR |
A multi-platform user interface for drawing highly customizable graphs in R. It aims to be a valuable help to quickly draw publishable graphs without any knowledge of R commands. Six kinds of graph are available: histogram, box-and-whisker plot, bar plot, pie chart, curve and scatter plot.
| Package: | GrapheR |
| Type: | Package |
| Version: | 1.9-86-5 |
| Date: | 2023-11-06 |
| License: | GPL-2 |
| LazyLoad: | yes |
Maxime HERVE
Maintainer: Maxime HERVE <[email protected]>
DALGAARD P (2001) A Primer on the R-Tcl/Tk Package. R News, 1(3), 27–31.
DALGAARD P (2002) Changes to the R-Tcl/Tk Package. R News, 2(3), 25–27.
HERVE M (2011) GrapheR: a multiplatform GUI for drawing customizable graphs in R. The R Journal, 3(2), 45–53.
## Not run: # To launch or re-launch the interface after closing: run.GrapheR() ## End(Not run)## Not run: # To launch or re-launch the interface after closing: run.GrapheR() ## End(Not run)
The function launches GrapheR. Use it after closing the interface to re-launch it.
run.GrapheR(lang = NULL, path.to.save = NULL, figurej = FALSE)run.GrapheR(lang = NULL, path.to.save = NULL, figurej = FALSE)
lang |
language, when the interface is relaunched. |
path.to.save |
if not |
figurej |
if |
Maxime HERVE <[email protected]>
An illustrative and fictive dataset about African and European swallows.
SwallowsSwallows
Species
Sex
Size
Weight
Coconuts
Distance